==> open-xchange-drive_7.8.3.orig.tar.bz2: open-xchange-drive-7.8.3/com.openexchange.drive.impl/src/com/openexchange/drive/impl/actions/ErrorDirectoryAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.drive.impl.actions;

import com.openexchange.drive.Action;
import com.openexchange.drive.DirectoryVersion;
import com.openexchange.drive.impl.comparison.ThreeWayComparison;
import com.openexchange.exception.OXException;

/**
 * {@link ErrorDirectoryAction}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class ErrorDirectoryAction extends AbstractDirectoryAction {

    /**
     * Initializes a new {@link ErrorDirectoryAction}.
     *
     * @param version The directory version
     * @param newVersion The new directory version
     * @param comparison The comparison
     * @param error The error
     * @param quarantine <code>true</code> to set the 'quarantine' flag, <code>false</code>, otherwise
     * @param stop <code>true</code> to set the 'stop' flag, <code>false</code>, otherwise
     */
    public ErrorDirectoryAction(DirectoryVersion version, DirectoryVersion newVersion, ThreeWayComparison<DirectoryVersion> comparison,
        OXException error, boolean quarantine, boolean stop) {
        super(version, newVersion, comparison);
        parameters.put(PARAMETER_ERROR, error);
        parameters.put(PARAMETER_QUARANTINE, Boolean.valueOf(quarantine));
        parameters.put(PARAMETER_STOP, Boolean.valueOf(stop));
    }

    @Override
    public Action getAction() {
        return Action.ERROR;
    }

}

==> open-xchange-drive_7.8.4.orig.tar.bz2: open-xchange-drive-7.8.4/com.openexchange.drive.impl/src/com/openexchange/drive/impl/actions/ErrorDirectoryAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.drive.impl.actions;

import com.openexchange.drive.Action;
import com.openexchange.drive.DirectoryVersion;
import com.openexchange.drive.impl.comparison.ThreeWayComparison;
import com.openexchange.exception.OXException;

/**
 * {@link ErrorDirectoryAction}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class ErrorDirectoryAction extends AbstractDirectoryAction {

    /**
     * Initializes a new {@link ErrorDirectoryAction}.
     *
     * @param version The directory version
     * @param newVersion The new directory version
     * @param comparison The comparison
     * @param error The error
     * @param quarantine <code>true</code> to set the 'quarantine' flag, <code>false</code>, otherwise
     * @param stop <code>true</code> to set the 'stop' flag, <code>false</code>, otherwise
     */
    public ErrorDirectoryAction(DirectoryVersion version, DirectoryVersion newVersion, ThreeWayComparison<DirectoryVersion> comparison,
        OXException error, boolean quarantine, boolean stop) {
        super(Action.ERROR, version, newVersion, comparison);
        parameters.put(PARAMETER_ERROR, error);
        parameters.put(PARAMETER_QUARANTINE, Boolean.valueOf(quarantine));
        parameters.put(PARAMETER_STOP, Boolean.valueOf(stop));
    }

}
